/**
 * Clase encargada de dibujar la GUI (Grafic User Interface)
 * @author Nicolas Sanz y Michael Vicencio
 */
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.event.*;
import java.util.*;
import java.io.*;

public class Gui {
    
    private JFrame frame;
    private JMenuBar jMenuBar1;
    private JMenu jMenuArchivo;
    private JMenuItem jMenuItem1Archivo;
    private JMenuItem jMenuItem2Archivo;
    private JMenu jMenuAccion;
    private JMenuItem jMenuItem1Accion;
    private JMenuItem jMenuItem2Accion;
    private JMenuItem jMenuItemAbout;
    private JList jList1;
    private JList jList2;
    private JSplitPane jSplitPane1;
    private JDialog jDialogAbout = null;
    private String arch;
    private String[] listilla;
   
    /**
     * Metodo que se encarga de dibujar y Mostrar la GUI.
     */
    public void CreaMuestraGui() {
        //Create and set up the window.
        frame = new JFrame("Tarea 2 DPOO");
        frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);

        JLabel emptyLabel = new JLabel("");
        emptyLabel.setPreferredSize(new Dimension(175, 100));
        frame.getContentPane().add(emptyLabel, BorderLayout.CENTER);

        //MENU
        jMenuBar1 = new JMenuBar();
        jMenuArchivo = new JMenu("Archivo");
        jMenuItem1Archivo = new JMenuItem("Abrir");
        jMenuItem1Archivo.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent evt) {
                jMenuItem1ArchivoActionPerformed(evt);
            }
        });
        jMenuItem2Archivo = new JMenuItem("Terminar");
        jMenuItem2Archivo.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent evt) {
                jMenuItem2ArchivoActionPerformed(evt);
            }
        });
        jMenuArchivo.add(jMenuItem1Archivo);
        jMenuArchivo.add(jMenuItem2Archivo);
        jMenuBar1.add(jMenuArchivo);
        jMenuAccion = new JMenu("Accion");
        jMenuItem1Accion = new JMenuItem("Rodar");
        jMenuItem1Accion.addActionListener(new ActionListener(){
            public void actionPerformed(ActionEvent evt){
                jMenuItem1AccionActionPerformed(evt);
            }
        });
        jMenuAccion.add(jMenuItem1Accion);
        jMenuItem2Accion = new JMenuItem("Buscar");
        jMenuItem2Accion.addActionListener(new ActionListener(){
            public void actionPerformed(ActionEvent evt){
                jMenuItem2AccionActionPerformed(evt);
            }
        });
        jMenuAccion.add(jMenuItem2Accion);
        jMenuBar1.add(jMenuAccion);
        jMenuItemAbout = new JMenuItem("About");
        jMenuItemAbout.addActionListener(new ActionListener(){
            public void actionPerformed(ActionEvent evt){
                jMenuItemAboutActionPerformed(evt);
            }
        });
        jMenuBar1.add(jMenuItemAbout);
        frame.setJMenuBar(jMenuBar1);

        
        //CONTENIDO
        DefaultListModel listModel = new DefaultListModel();
                
        jList1 = new JList();
        jList1.setModel(listModel);
        jList1.setSelectionMode(ListSelectionModel.MULTIPLE_INTERVAL_SELECTION);
        JScrollPane jScrollPane1 = new JScrollPane();
        jScrollPane1.setViewportView(jList1);
        
        jList2 = new JList();
        jList2.setModel(listModel);
        jList2.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
        JScrollPane jScrollPane2 = new JScrollPane();
        jScrollPane2.setViewportView(jList2);
        
        jSplitPane1 = new JSplitPane();
        jSplitPane1.setLeftComponent(jScrollPane1);
        jSplitPane1.setRightComponent(jScrollPane2);
        jSplitPane1.setDividerLocation(0.5);
        
        
        
        frame.add(jSplitPane1);
        
        //Display the window.
        frame.setSize(500,400);
        frame.setLocationRelativeTo(null);
        frame.setVisible(true);
        
        
    }
    /**
     * Metodo encargado de ejecutar la accion de Abrir un archivo
     * @param evt identificador del evento que llamo a este metodo.
     */
    private void  jMenuItem1ArchivoActionPerformed(ActionEvent evt) {
        JFileChooser jFileChooser1 = new JFileChooser();       
        int seleccion = jFileChooser1.showOpenDialog(jMenuBar1);
        if(seleccion == JFileChooser.APPROVE_OPTION){
            File f = jFileChooser1.getSelectedFile();
            arch = f.toString();
            Importador imp = new Importador(arch);
            listilla = imp.getNombresEstudiantes();
            jList1.setListData(listilla);
        }
    }
    /**
     * Metodo encargado de cerrar la aplicacion
     * @param evt identificador del evento que llamo a este metodo.
     */
    private void  jMenuItem2ArchivoActionPerformed(ActionEvent evt) {
        System.exit(0);
    }
    /**
     * Metodo que implementa la accion de Rodar.
     * @param evt identificador del evento que llamo a este metodo.
     */
    private void  jMenuItem1AccionActionPerformed(ActionEvent evt) {
        Rodador rod = new Rodador(listilla);
        jList2.setListData(rod.getDatosOrdenados());
    }
    /**
     * Metodo que implementa la busqueda.
     * @param evt identificador del evento que llamo a este metodo.
     */
    private void  jMenuItem2AccionActionPerformed(ActionEvent evt) {
        String s = (String)JOptionPane.showInputDialog((Frame) SwingUtilities.getWindowAncestor((Component) evt.getSource()),
                                                         "Ingrese el Nombre o Apellido\n"
                                                         + "de algun alumno de la lista",
                                                        "Buscar",
                                                        JOptionPane.PLAIN_MESSAGE);
        if ((s != null) && (s.length() > 0)) {
            Buscador b = new Buscador(s,listilla);
            jList1.setSelectedIndices(b.dameEncontrados());
        }


    }
    /**
     * Metodo que implementa el about.
     * @param evt
     */
    private void  jMenuItemAboutActionPerformed(ActionEvent evt) {
        if (jDialogAbout == null)
        {
            jDialogAbout = new JDialog((Frame) SwingUtilities.getWindowAncestor((Component) evt.getSource()));
            jDialogAbout.setTitle("About");
            jDialogAbout.getContentPane().setLayout(new BoxLayout(jDialogAbout.getContentPane(),BoxLayout.Y_AXIS));
            
            JLabel j1 = new JLabel("Integrantes:");            
            JLabel j2 = new JLabel("Nicolas Sanz");            
            JLabel j3 = new JLabel("Michael Vicencio");            
            JLabel j4 = new JLabel("Profesor:");            
            JLabel j5 = new JLabel("Agustin Gonzales");            
            JLabel j6 = new JLabel("Fecha:");
            JLabel j7 = new JLabel("05-Jun-2008");
            j1.setAlignmentX(Component.RIGHT_ALIGNMENT);
            j2.setAlignmentX(Component.LEFT_ALIGNMENT);
            j3.setAlignmentX(Component.LEFT_ALIGNMENT);
            j4.setAlignmentX(Component.RIGHT_ALIGNMENT);
            j5.setAlignmentX(Component.LEFT_ALIGNMENT);
            j6.setAlignmentX(Component.RIGHT_ALIGNMENT);
            j7.setAlignmentX(Component.LEFT_ALIGNMENT);
            jDialogAbout.getContentPane().add(j1);
            jDialogAbout.getContentPane().add(j2);
            jDialogAbout.getContentPane().add(j3);
            jDialogAbout.getContentPane().add(j4);
            jDialogAbout.getContentPane().add(j5);
            jDialogAbout.getContentPane().add(j6);
            jDialogAbout.getContentPane().add(j7);
            jDialogAbout.pack();
            jDialogAbout.setLocationRelativeTo(frame);
        }

        jDialogAbout.setVisible(true);
    }
    
}
